@@ -9,6 +9,7 @@ from .validator import (
 )
 from .nested_json import JsonParam
 from .valid_request import ValidRequest
+from .after_param import AbstractAfterParam
 from .rules import (
     AbstractRule,
     CompositeRule,
@@ -22,4 +23,6 @@ from .rules import (
     NotEmpty,
     Pattern,
     Datetime,
+    Number,
+    REGEX_EMAIL,
 )
