@@ -7,6 +7,10 @@ class RequestError(Exception):
     """
 
 
+class AfterParamError(RequestError):
+    pass
+
+
 class WrongUsageError(RequestError):
     pass
 
@@ -18,6 +22,19 @@ class JsonError(RequestError):
         self.as_list = as_list
 
 
+class JsonListExpectedError(JsonError):
+    def __init__(self, depth: List[str]):
+        self.depth = depth
+
+    def __str__(self) -> str:
+        return 'list type expected'
+
+
+class JsonDictExpectedError(JsonListExpectedError):
+    def __str__(self) -> str:
+        return 'dict type expected'
+
+
 class JsonListItemTypeError(RequestError):
     """
     Raises when invalid type of list item.
@@ -119,6 +136,11 @@ class ValueEmailError(RuleError):
         return 'invalid email address'
 
 
+class NumberError(RuleError):
+    def __str__(self) -> str:
+        return 'expected number'
+
+
 class ValueDatetimeError(RuleError):
     def __init__(self, dt_format: str) -> None:
         self.dt_format = dt_format
